# Changelog

All notable changes to this project will be documented in this file.

## [0.0.1] - 2024-12-14

### Added

- Initial release
- Interactive CLI mode
- Local RAG pipeline support
- Document management with ChromaDB
